@@ -42,6 +42,7 @@ import re
 import xml.parsers.expat as expat
 import getpass
 import locale
+import htmlentitydefs
 
 try:
     import platform
@@ -54,6 +55,9 @@ from g import *
 from codes import *
 import pexpect
 
+BIG_ENDIAN = 0
+LITTLE_ENDIAN = 1
+
 
 
 def lock(f):
@@ -102,7 +106,7 @@ def lock_app(application, suppress_error=False):
     return True, lock_file_f
 
 
-xml_basename_pat = re.compile(r"""HPLIP-(\d*)_(\d*)_(\d*).xml""", re.IGNORECASE)
+#xml_basename_pat = re.compile(r"""HPLIP-(\d*)_(\d*)_(\d*).xml""", re.IGNORECASE)
 
 
 def Translator(frm='', to='', delete='', keep=None):
@@ -302,7 +306,6 @@ class Queue(Stack):
 
 
 
-
 # RingBuffer class
 # Source: Python Cookbook 1st Ed., sec. 5.18, pg. 201
 # Credit: Sebastien Keim
@@ -393,7 +396,6 @@ except AttributeError:
 
 
 
-
 def which(command, return_full_path=False):
     path = os.getenv('PATH').split(':')
 
@@ -422,7 +424,7 @@ def which(command, return_full_path=False):
         return found_path
 
 
-class UserSettings(object): # Note: Deprecated after 2.8.8 (see ui4/ui_utils.py)
+class UserSettings(object): # Note: Deprecated after 2.8.8 in Qt4 (see ui4/ui_utils.py)
     def __init__(self):
         self.load()
 
@@ -570,6 +572,7 @@ def canEnterGUIMode(): # qt3
 
     return True
 
+
 def canEnterGUIMode4(): # qt4
     if not prop.gui_build:
         log.warn("GUI mode disabled in build.")
@@ -585,6 +588,7 @@ def canEnterGUIMode4(): # qt4
 
     return True
 
+
 def checkPyQtImport(): # qt3
     # PyQt
     try:
@@ -634,6 +638,7 @@ def checkPyQtImport(): # qt3
 
     return True
 
+
 def checkPyQtImport4():
     try:
         import PyQt4
@@ -737,6 +742,7 @@ except ImportError:
                                  self.pattern)
             return self.pattern.sub(convert, self.template)
 
+
         def safe_substitute(self, *args, **kws):
             if len(args) > 1:
                 raise TypeError('Too many positional arguments')
@@ -785,9 +791,11 @@ def cat(s):
 
     return Template(s).substitute(sys._getframe(1).f_globals, **locals)
 
+
 identity = string.maketrans('','')
 unprintable = identity.translate(identity, string.printable)
 
+
 def printable(s):
     return s.translate(identity, unprintable)
 
@@ -797,14 +805,17 @@ def any(S,f=lambda x:x):
         if f(x): return True
     return False
 
+
 def all(S,f=lambda x:x):
     for x in S:
         if not f(x): return False
     return True
 
+
 BROWSERS = ['firefox', 'mozilla', 'konqueror', 'galeon', 'skipstone'] # in preferred order
 BROWSER_OPTS = {'firefox': '-new-window', 'mozilla' : '', 'konqueror': '', 'galeon': '-w', 'skipstone': ''}
 
+
 def find_browser():
     if platform_avail and platform.system() == 'Darwin':
         return "open"
@@ -815,7 +826,8 @@ def find_browser():
         else:
             return None
 
-def openURL(url):
+
+def openURL(url, use_browser_opts=True):
     if platform_avail and platform.system() == 'Darwin':
         cmd = 'open "%s"' % url
         log.debug(cmd)
@@ -825,7 +837,10 @@ def openURL(url):
             bb = which(b)
             if bb:
                 bb = os.path.join(bb, b)
-                cmd = """%s %s "%s" &""" % (bb, BROWSER_OPTS[b], url)
+                if use_browser_opts:
+                    cmd = """%s %s "%s" &""" % (bb, BROWSER_OPTS[b], url)
+                else:
+                    cmd = """%s "%s" &""" % (bb, url)
                 log.debug(cmd)
                 os.system(cmd)
                 break
@@ -870,12 +885,12 @@ class XMLToDictParser:
 
     def startElement(self, name, attrs):
         #print "START:", name, attrs
-        self.stack.append(str(name).lower())
-        self.last_start = str(name).lower()
+        self.stack.append(unicode(name).lower())
+        self.last_start = unicode(name).lower()
 
         if len(attrs):
             for a in attrs:
-                self.stack.append(str(a).lower())
+                self.stack.append(unicode(a).lower())
                 self.addData(attrs[a])
                 self.stack.pop()
 
@@ -887,7 +902,7 @@ class XMLToDictParser:
         self.stack.pop()
 
     def charData(self, data):
-        data = str(data).strip()
+        data = unicode(data).strip()
 
         if data and self.stack:
             self.addData(data)
@@ -898,7 +913,7 @@ class XMLToDictParser:
         try:
             data = int(data)
         except ValueError:
-            data = str(data)
+            data = unicode(data)
 
         stack_str = '-'.join(self.stack)
         stack_str_0 = '-'.join([stack_str, '0'])
@@ -914,9 +929,9 @@ class XMLToDictParser:
                 j = 2
                 while True:
                     try:
-                        self.data['-'.join([stack_str, str(j)])]
+                        self.data['-'.join([stack_str, unicode(j)])]
                     except KeyError:
-                        self.data['-'.join([stack_str, str(j)])] = data
+                        self.data['-'.join([stack_str, unicode(j)])] = data
                         break
                     j += 1
 
@@ -931,13 +946,14 @@ class XMLToDictParser:
         parser.StartElementHandler = self.startElement
         parser.EndElementHandler = self.endElement
         parser.CharacterDataHandler = self.charData
-        parser.Parse(text, True)
+        parser.Parse(text.encode('utf-8'), True)
         return self.data
 
 
 def dquote(s):
     return ''.join(['"', s, '"'])
 
+
 # Python 2.2.x compatibility functions (strip() family with char argument added in Python 2.2.3)
 if sys.hexversion < 0x020203f0:
     def xlstrip(s, chars=' '):
@@ -971,6 +987,7 @@ def getBitness():
     else:
         return struct.calcsize("P") << 3
 
+
 def getProcessor():
     if platform_avail:
         return platform.machine().replace(' ', '_').lower() # i386, i686, power_macintosh, etc.
@@ -978,15 +995,6 @@ def getProcessor():
         return "i686" # TODO: Need a fix here
 
 
-BIG_ENDIAN = 0
-LITTLE_ENDIAN = 1
-
-#def getEndian():
-    #if struct.pack("@I", 0x01020304)[0] == '\x01':
-        #return BIG_ENDIAN
-    #else:
-        #return LITTLE_ENDIAN
-
 def getEndian():
     if sys.byteorder == 'big':
         return BIG_ENDIAN
@@ -997,6 +1005,20 @@ def getEndian():
 def get_password():
     return getpass.getpass("Enter password: ")
 
+def get_password_ui():
+    fp = open("/etc/hp/hplip.conf", "r")
+    qt = "qt3"
+    for line in fp:
+        if string.find(line, "qt4") is not -1 and string.find(line, "yes") is not -1:
+            qt = "qt4"
+    fp.close()
+    if qt is "qt4":
+        from ui4.setupdialog import showPasswordUI
+        username, password = showPasswordUI("Your printer requires to install HP proprietary plugin\nPlease enter root/superuser password to continue")
+    if qt is "qt3":
+        from ui.setupform import showPasswordUI
+        username, password = showPasswordUI("Your priter requires to install HP proprietary plugin\nPlease enter root/superuser password to continue")
+    return password
 
 def run(cmd, log_output=True, password_func=get_password, timeout=1):
     output = cStringIO.StringIO()
@@ -1018,7 +1040,10 @@ def run(cmd, log_output=True, password_func=get_password, timeout=1):
 
             if i == 0: # Password:
                 if password_func is not None:
-                    child.sendline(password_func())
+                    if password_func == "get_password_ui":
+                        child.sendline(get_password_ui())
+                    else:
+                        child.sendline(password_func())
                 else:
                     child.sendline(get_password())
 
@@ -1528,7 +1553,7 @@ encoding: utf8
         log.info("contact the HPLIP Team.")
 
         log.info(".SH COPYRIGHT")
-        log.info("Copyright (c) 2001-8 Hewlett-Packard Development Company, L.P.")
+        log.info("Copyright (c) 2001-9 Hewlett-Packard Development Company, L.P.")
         log.info(".LP")
         log.info("This software comes with ABSOLUTELY NO WARRANTY.")
         log.info("This is free software, and you are welcome to distribute it")
@@ -1547,7 +1572,7 @@ def log_title(program_name, version, show_ver=True): # TODO: Move to base/module
 
     log.info(log.bold("%s ver. %s" % (program_name, version)))
     log.info("")
-    log.info("Copyright (c) 2001-8 Hewlett-Packard Development Company, LP")
+    log.info("Copyright (c) 2001-9 Hewlett-Packard Development Company, LP")
     log.info("This software comes with ABSOLUTELY NO WARRANTY.")
     log.info("This is free software, and you are welcome to distribute it")
     log.info("under certain conditions. See COPYING file for more details.")
@@ -1559,6 +1584,66 @@ def ireplace(old, search, replace):
     return re.sub(regex, replace, old)
 
 
+def su_sudo():
+    su_sudo_str = None
+
+    if which('kdesu'):
+        su_sudo_str = 'kdesu -- %s'
+
+    elif which('gnomesu'):
+        su_sudo_str = 'gnomesu -c "%s"'
+
+    elif which('gksu'):
+        su_sudo_str = 'gksu "%s"'
+    
+    elif which('su'):
+        su_sudo_str = 'su'
+
+    return su_sudo_str
 
 
+#
+# Removes HTML or XML character references and entities from a text string.
+#
 
+def unescape(text):
+    def fixup(m):
+        text = m.group(0)
+        if text[:2] == "&#":
+            # character reference
+            try:
+                if text[:3] == "&#x":
+                    #return unichr(int(text[3:-1], 16))
+                    return chr(int(text[3:-1], 16))
+                else:
+                    #return unichr(int(text[2:-1]))
+                    return chr(int(text[2:-1]))
+            except ValueError:
+                pass
+        else:
+            # named entity
+            try:
+                #text = unichr(htmlentitydefs.name2codepoint[text[1:-1]])
+                text = chr(htmlentitydefs.name2codepoint[text[1:-1]])
+            except KeyError:
+                pass
+        return text # leave as is
+    return re.sub("&#?\w+;", fixup, text)
+
+
+# Adds HTML or XML character references and entities from a text string
+
+def escape(s):
+    if not isinstance(s, unicode):
+        s = unicode(s) # hmmm...
+
+    s = s.replace(u"&", u"&amp;")
+
+    for c in htmlentitydefs.codepoint2name:
+        if c != 0x26: # exclude &
+            s = s.replace(unichr(c), u"&%s;" % htmlentitydefs.codepoint2name[c])
+
+    for c in range(0x20) + range(0x7f, 0xa0):
+        s = s.replace(unichr(c), u"&#%d;" % c)
+
+    return s
