@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+﻿# -*- coding: utf-8 -*-
 #
 # (c) Copyright 2003-2009 Hewlett-Packard Development Company, L.P.
 #
@@ -249,6 +249,7 @@ class CoreInstall(object):
             'package_arch' : TYPE_LIST,
             'add_user_to_group': TYPE_STRING,
             'open_mdns_port' : TYPE_LIST, # command to use to open mdns multicast port 5353
+            'acl_rules' : TYPE_BOOL, # Use ACL uDEV rules (Ubuntu 9.10+)
         }
 
         # components
@@ -1042,8 +1043,7 @@ class CoreInstall(object):
 
     def check_policykit(self):
         log.debug("Checking for PolicyKit...")
-        return check_file('PolicyKit.conf', "/etc/PolicyKit") and check_file('org.gnome.PolicyKit.AuthorizationManager.service', "/usr/share/dbus-1/services")
-
+        return (check_file('PolicyKit.conf', "/etc/PolicyKit") and check_file('org.gnome.PolicyKit.AuthorizationManager.service', "/usr/share/dbus-1/services")) or (check_file('50-localauthority.conf', "/etc/polkit-1/localauthority.conf.d") and check_file('org.freedesktop.PolicyKit1.service', "/usr/share/dbus-1/system-services"))
 
     def check_pkg_mgr(self):
         """
@@ -1196,6 +1196,9 @@ class CoreInstall(object):
         if self.get_distro_ver_data('cups_path_with_bitness', False) and self.bitness == 64:
             configure_cmd += ' --with-cupsbackenddir=/usr/lib64/cups/backend --with-cupsfilterdir=/usr/lib64/cups/filter'
 
+        if self.get_distro_ver_data('acl_rules', False):
+            configure_cmd += ' --enable-udev-acl-rules'
+
         if self.enable is not None:
             for c in self.enable:
                 configuration[c] = True
@@ -1212,6 +1215,109 @@ class CoreInstall(object):
 
         return configure_cmd
 
+    def configure_html(self):
+        configure_cmd = './configure'
+        configure_cmd += ' --prefix=/usr' 
+        configure_cmd += ' --with-hpppddir=%s' % self.ppd_dir
+
+        if self.bitness == 64:
+            configure_cmd += ' --libdir=/usr/lib64'
+
+        self.ui_toolkit =  self.get_distro_ver_data('ui_toolkit') 
+        if self.ui_toolkit is not None and self.ui_toolkit == 'qt3':
+            configure_cmd += ' --enable-qt3 --disable-qt4'
+        else:
+            configure_cmd += ' --enable-qt4'
+
+        self.native_cups =  self.get_distro_ver_data('native_cups')
+        if self.native_cups is not None and self.native_cups == 1:
+            configure_cmd += ' --enable-hpcups-install --enable-cups-drv-install --enable-cups-ppd-install --disable-hpijs-install --disable-foomatic-drv-install --disable-foomatic-ppd-install --disable-foomatic-rip-hplip-install' 
+        else:
+            configure_cmd += ' --disable-hpcups-install --disable-cups-drv-install --disable-cups-ppd-install --enable-hpijs-install --enable-foomatic-drv-install --enable-foomatic-ppd-install --enable-foomatic-rip-hplip-install' 
+
+        self.fax_supported =  self.get_distro_ver_data('fax_supported')
+        if self.fax_supported is None:
+            configure_cmd += ' --disable-fax-build --disable-dbus-build'
+        else:
+	    configure_cmd += ' --enable-fax-build --enable-dbus-build'
+
+        self.network_supported = self.get_distro_ver_data('network_supported')
+        if self.network_supported is None:
+            configure_cmd += ' --disable-network-build'
+	else:
+	    configure_cmd += ' --enable-network-build'
+          
+        self.scan_supported = self.get_distro_ver_data('scan_supported')
+        if self.scan_supported is None:
+            configure_cmd += ' --disable-scan-build'
+	else:
+	    configure_cmd += ' --enable-scan-build'
+  
+        self.policykit = self.get_distro_ver_data('policykit')
+        if self.policykit is not None and self.policykit == 1:
+            configure_cmd += ' --enable-policykit'
+	else:
+	    configure_cmd += ' --disable-policykit'
+	
+        return configure_cmd
+
+    def configure_qt4(self):
+        configure_cmd = './configure'
+        configure_cmd += ' --prefix=/usr'
+        configure_cmd += ' --with-hpppddir=%s' % self.ppd_dir
+
+        if self.bitness == 64:
+            configure_cmd += ' --libdir=/usr/lib64'
+
+        self.ui_toolkit =  self.get_distro_ver_data('ui_toolkit')
+        if self.ui_toolkit is not None and self.ui_toolkit == 'qt3':
+            configure_cmd += ' --enable-qt3 --disable-qt4'
+        else:
+            configure_cmd += ' --enable-qt4'
+
+        self.native_cups =  self.get_distro_ver_data('native_cups')
+        self.ppd_install = self.get_distro_ver_data('ppd_install')
+        if self.native_cups is not None and self.native_cups == 1:
+            configure_cmd += ' --enable-hpcups-install'
+	    if self.ppd_install == 'drv':
+	        configure_cmd += ' --enable-cups-drv-install --disable-cups-ppd-install'
+	    else:
+		configure_cmd += ' --enable-cups-ppd-install --disable-cups-drv-install'
+	    configure_cmd += ' --disable-hpijs-install --disable-foomatic-drv-install --disable-foomatic-ppd-install --disable-foomatic-rip-hplip-install'
+        else:
+	    configure_cmd += ' --enable-hpijs-install'
+	    if self.ppd_install == 'drv':
+	        configure_cmd += ' --enable-foomatic-drv-install --disable-foomatic-ppd-install'
+	    else:
+		configure_cmd += ' --enable-foomatic-ppd-install --disable-foomatic-drv-install'
+	    configure_cmd += ' --enable-foomatic-rip-hplip-install --disable-hpcups-install --disable-cups-drv-install --disable-cups-ppd-install'
+
+        self.fax_supported =  self.get_distro_ver_data('fax_supported')
+        if self.fax_supported is None:
+            configure_cmd += ' --disable-fax-build --disable-dbus-build'
+        else:
+            configure_cmd += ' --enable-fax-build --enable-dbus-build'
+
+        self.network_supported = self.get_distro_ver_data('network_supported')
+        if self.network_supported is None:
+            configure_cmd += ' --disable-network-build'
+        else:
+            configure_cmd += ' --enable-network-build'
+
+        self.scan_supported = self.get_distro_ver_data('scan_supported')
+        if self.scan_supported is None:
+            configure_cmd += ' --disable-scan-build'
+        else:
+            configure_cmd += ' --enable-scan-build'
+
+        self.policykit = self.get_distro_ver_data('policykit')
+        if self.policykit is not None and self.policykit == 1:
+            configure_cmd += ' --enable-policykit'
+        else:
+            configure_cmd += ' --disable-policykit'
+
+        return configure_cmd
+
 
     def restart_cups(self):
         if os.path.exists('/etc/init.d/cups'):
@@ -1378,7 +1484,6 @@ class CoreInstall(object):
                             yield d, self.dependencies[d][2], opt
                             # depend, desc, option
 
-
     def missing_optional_dependencies(self):
         # missing deps in opt. options
         for opt in self.components[self.selected_component][1]:
@@ -1392,14 +1497,27 @@ class CoreInstall(object):
 
         # opt. deps in req. options
         for opt in self.components[self.selected_component][1]:
-              if self.options[opt][0]: # required options
-                  for d in self.options[opt][2]: # dependencies for option
-                      if not self.dependencies[d][0]: # optional dep
-                          if not self.have_dependencies[d]: # missing
-                              log.debug("Missing optional dependency: %s" % d)
-                              yield d, self.dependencies[d][2], self.dependencies[d][0], opt
-                              # depend, desc, option
-
+            if self.options[opt][0]: # required options
+                for d in self.options[opt][2]: # dependencies for option
+                    if d == 'cups-ddk':
+                        status, output = self.run('cups-config --version')
+                        import string
+                        if status == 0 and (string.count(output, '.') == 1 or string.count(output, '.') == 2):
+                            if string.count(output, '.') == 1:
+                                major, minor = string.split(output, '.', 2)
+                            if string.count(output, '.') == 2:
+                                major, minor, release = string.split(output, '.', 3)
+                            if len(minor) > 1 and minor[1] >= '0' and minor[1] <= '9':
+                                minor = ((ord(minor[0]) - ord('0')) * 10) + (ord(minor[1]) - ord('0'))
+                            else:
+                                minor = ord(minor[0]) - ord('0')
+                            if major > '1' or (major == '1' and minor >= 4):
+                                continue
+	            if not self.dependencies[d][0]: # optional dep
+                        if not self.have_dependencies[d]: # missing
+                            log.debug("Missing optional dependency: %s" % d)
+                            yield d, self.dependencies[d][2], self.dependencies[d][0], opt
+                            # depend, desc, option
 
     def select_options(self, answer_callback):
         num_opt_missing = 0
@@ -1806,7 +1924,7 @@ class CoreInstall(object):
         try:
             filename, headers = urllib.urlretrieve(url, plugin_file, callback)
         except IOError, e:
-            #log.error("Plug-in download failed: %s" % e.strerror)
+            log.error("Plug-in download failed: %s" % e.strerror)
             return PLUGIN_INSTALL_ERROR_PLUGIN_FILE_NOT_FOUND, e.strerror
 
         if self.isErrorPage(file(plugin_file, 'r').read(1024)):
@@ -1826,7 +1944,7 @@ class CoreInstall(object):
         try:
             filename, headers = urllib.urlretrieve(digsig_url, digsig_file, callback)
         except IOError, e:
-            #log.error("Plug-in GPG file download failed: %s" % e.strerror)
+            log.error("Plug-in GPG file download failed: %s" % e.strerror)
             return PLUGIN_INSTALL_ERROR_DIGITAL_SIG_NOT_FOUND, e.strerror
 
         if self.isErrorPage(file(digsig_file, 'r').read(1024)):
@@ -1837,10 +1955,10 @@ class CoreInstall(object):
         gpg = utils.which('gpg')
         if gpg:
             gpg = os.path.join(gpg, 'gpg')
-            cmd = '%s --no-permission-warning --keyserver pgp.mit.edu --recv-keys 0x9013c005' % gpg
+            cmd = '%s --no-permission-warning --keyserver pgp.mit.edu --recv-keys 0xA59047B9' % gpg
             log.info("Receiving digital keys: %s" % cmd)
             status, output = self.run(cmd)
-            #log.debug(output)
+            log.debug(output)
 
             if status != 0:
                 return PLUGIN_INSTALL_ERROR_UNABLE_TO_RECV_KEYS, status
@@ -1877,7 +1995,11 @@ class CoreInstall(object):
         if mode == GUI_MODE:
             return os.system("sh %s --nox11 -- -u" % plugin_file) == 0
         else:
-            return os.system("sh %s --nox11 -- -i" % plugin_file) == 0
+            if os.system("sh %s --nox11 -- -i" % plugin_file) == 0:
+                return True
+            else:
+                log.error("Python gobject/dbus may be not installed")
+                return False
 
 
     def delete_plugin(self):
