@@ -183,6 +183,10 @@ enum HPMUD_RESULT __attribute__ ((visibility ("hidden"))) service_to_channel(mud
    {
       *index = HPMUD_PRINT_CHANNEL;
    }
+   else if (strncasecmp(sn, "hp-ews-ledm", 11) == 0)
+   {
+      *index = HPMUD_EWS_LEDM_CHANNEL;
+   }
    else if (strncasecmp(sn, "hp-ews", 6) == 0)
    {
       *index = HPMUD_EWS_CHANNEL;
@@ -199,6 +203,10 @@ enum HPMUD_RESULT __attribute__ ((visibility ("hidden"))) service_to_channel(mud
    {
       *index = HPMUD_MARVELL_SCAN_CHANNEL;
    }
+   else if (strncasecmp(sn, "hp-marvell-fax", 14) == 0)
+   {
+      *index = HPMUD_MARVELL_FAX_CHANNEL;
+   }
    /* All the following services require MLC/1284.4. */
    else if (pd->io_mode == HPMUD_RAW_MODE || pd->io_mode == HPMUD_UNI_MODE)
    {
@@ -423,9 +431,11 @@ int hpmud_get_uri_model(const char *uri, char *buf, int buf_size)
 int hpmud_get_uri_datalink(const char *uri, char *buf, int buf_size)
 {
    char *p;
-   char ip[HPMUD_LINE_SIZE];
    int i;
    int zc=0;
+#ifdef HAVE_LIBNETSNMP
+   char ip[HPMUD_LINE_SIZE];
+#endif
 
    buf[0] = 0;
 
