@@ -61,7 +61,7 @@ enum hpaioOption_e {
                     OPTION_JPEG_COMPRESSION_FACTOR,
                     OPTION_BATCH_SCAN,
                     OPTION_ADF_MODE, 
-//                    OPTION_DUPLEX,
+                    OPTION_DUPLEX,
 
     GROUP_GEOMETRY,
                     OPTION_LENGTH_MEASUREMENT,
@@ -189,6 +189,7 @@ struct  hpaioScanner_s
         int ip_done;
         int page_done;
         int upload_state;                                 /* last pml upload state */
+        int user_cancel;                                  /* user cancelled operation */
 
         struct 
         {
